Crate reqmd_cli

Crate reqmd_cli 

Structs

Target
Describes a selection in a markdown file should be considered for an operation. This can be parsed from a string with the following format:
TimeoutDuration
Timeout Duration

Enums

Selection
Describes a selection of a request in a markdown file. This can be a line number, an ordinal number, or the first or last request in the file.

Functions

dump_ast
Dump AST
list_requests
List Requests
send_request
Send Request